@@ -65,7 +65,7 @@ static ssize_t readwait(int fd, void *buf, size_t count) {
 		s = read(fd,buf,count);
 		if( s < 0 )
 			return s;
-		if( interupted() ) {
+		if( interrupted() ) {
 			errno = EINTR;
 			return -1;
 		}
@@ -87,7 +87,7 @@ retvalue ar_open(/*@out@*/struct ar_archive **n, const char *filename) {
 	char buffer[sizeof(AR_MAGIC)];
 	ssize_t bytesread;
 
-	if( interupted() )
+	if( interrupted() )
 		return RET_ERROR_INTERUPTED;
 	ar = calloc(1,sizeof(struct ar_archive));
 	if( ar == NULL )
@@ -160,7 +160,7 @@ retvalue ar_nextmember(struct ar_archive *ar,/*@out@*/char **filename) {
 	}
 	/* read the next header from the file */
 
-	if( interupted() )
+	if( interrupted() )
 		return RET_ERROR_INTERUPTED;
 
 	bytesread = readwait(ar->fd,&ar->currentheader,sizeof(ar->currentheader));
