@@ -44,6 +44,7 @@
 #include "checkindsc.h"
 #include "checkindeb.h"
 #include "checkin.h"
+#include "uploaderslist.h"
 
 extern int verbose;
 
@@ -102,6 +103,7 @@ struct changes {
 		       binaries;
 	struct fileentry *files;
 	char *control;
+	struct strlist fingerprints;
 	/* Things to be set by changes_fixfields: */
 	/* the component source files are put into */
 	const char *srccomponent;
@@ -150,6 +152,7 @@ static void changes_free(/*@only@*/struct changes *changes) {
 		free(changes->changesfilekey);
 //		trackedpackage_free(changes->trackedpkg);
 		free(changes->incomingdirectory);
+		strlist_done(&changes->fingerprints);
 	}
 	free(changes);
 }
@@ -374,10 +377,11 @@ static retvalue check(const char *filename,struct changes *changes,const char *f
 	return r;
 }
 
-static retvalue changes_read(const char *filename,/*@out@*/struct changes **changes,/*@null@*/const char *packagetypeonly,/*@null@*/const char *forcearchitecture, bool_t onlysigned) {
+static retvalue changes_read(const char *filename,/*@out@*/struct changes **changes,/*@null@*/const char *packagetypeonly,/*@null@*/const char *forcearchitecture) {
 	retvalue r;
 	struct changes *c;
 	struct strlist filelines;
+	bool_t broken;
 
 #define E(err) { \
 		if( r == RET_NOTHING ) { \
@@ -400,8 +404,15 @@ static retvalue changes_read(const char *filename,/*@out@*/struct changes **chan
 	c = calloc(1,sizeof(struct changes));
 	if( c == NULL )
 		return RET_ERROR_OOM;
-	r = signature_readsignedchunk(filename,&c->control,onlysigned);
+	r = signature_readsignedchunk(filename,&c->control,&c->fingerprints, NULL, &broken);
 	R;
+	if( broken && !IGNORING_(brokensignatures, 
+"'%s' contains only broken signatures.\n"
+"This most likely means the file was damaged (or edited improperly)\n",
+				filename) ) {
+		r = RET_ERROR;
+		R;
+	}
 	r = check(filename,c,"Format");
 	R;
 	r = check(filename,c,"Date");
@@ -829,7 +840,7 @@ static retvalue changes_deleteleftoverfiles(struct changes *changes,int delete)
 	return result;
 }
 
-static retvalue changes_checkpkgs(filesdb filesdb,struct distribution *distribution,struct changes *changes,const struct alloverrides *ao, bool_t onlysigned, const char *sourcedirectory) {
+static retvalue changes_checkpkgs(filesdb filesdb,struct distribution *distribution,struct changes *changes,const struct alloverrides *ao, const char *sourcedirectory) {
 	struct fileentry *e;
 	retvalue r;
 	bool_t somethingwasmissed = FALSE;
@@ -853,7 +864,9 @@ static retvalue changes_checkpkgs(filesdb filesdb,struct distribution *distribut
 				"deb",
 				distribution,fullfilename,
 				e->filekey,e->md5sum,
-				ao->deb,D_INPLACE,FALSE);
+				ao->deb,D_INPLACE,FALSE,
+				&changes->binaries,
+				changes->source,changes->version);
 			if( r == RET_NOTHING )
 				somethingwasmissed = TRUE;
 		} else if( e->type == fe_UDEB ) {
@@ -863,7 +876,9 @@ static retvalue changes_checkpkgs(filesdb filesdb,struct distribution *distribut
 				"udeb",
 				distribution,fullfilename,
 				e->filekey,e->md5sum,
-				ao->udeb,D_INPLACE,FALSE);
+				ao->udeb,D_INPLACE,FALSE,
+				&changes->binaries,
+				changes->source,changes->version);
 			if( r == RET_NOTHING )
 				somethingwasmissed = TRUE;
 		} else if( e->type == fe_DSC ) {
@@ -874,7 +889,8 @@ static retvalue changes_checkpkgs(filesdb filesdb,struct distribution *distribut
 				distribution,sourcedirectory,fullfilename,
 				e->filekey,e->basename,
 				changes->srcdirectory,e->md5sum,
-				ao->dsc,D_INPLACE,onlysigned);
+				ao->dsc,D_INPLACE,
+				changes->source,changes->version);
 			if( r == RET_NOTHING )
 				somethingwasmissed = TRUE;
 		}
@@ -903,7 +919,7 @@ static retvalue changes_includepkgs(const char *dbdir,references refs,struct dis
 			e = e->next;
 			continue;
 		}
-		if( interupted() ) {
+		if( interrupted() ) {
 			return RET_ERROR_INTERUPTED;
 		}
 		if( e->type == fe_DEB ) {
@@ -936,19 +952,67 @@ static retvalue changes_includepkgs(const char *dbdir,references refs,struct dis
 	return r;
 }
 
+static bool_t permissionssuffice(UNUSED(struct changes *changes),
+                                 const struct uploadpermissions *permissions) {
+	return permissions->allowall;
+}
+
 /* insert the given .changes into the mirror in the <distribution>
  * if forcecomponent, forcesection or forcepriority is NULL
  * get it from the files or try to guess it. */
-retvalue changes_add(const char *dbdir,trackingdb const tracks,references refs,filesdb filesdb,const char *packagetypeonly,const char *forcecomponent,const char *forcearchitecture,const char *forcesection,const char *forcepriority,struct distribution *distribution,const struct alloverrides *ao,const char *changesfilename,int delete,struct strlist *dereferencedfilekeys,bool_t onlysigned) {
+retvalue changes_add(const char *dbdir,trackingdb const tracks,references refs,filesdb filesdb,const char *packagetypeonly,const char *forcecomponent,const char *forcearchitecture,const char *forcesection,const char *forcepriority,struct distribution *distribution,struct uploaders *uploaders, const struct alloverrides *ao,const char *changesfilename,int delete,struct strlist *dereferencedfilekeys) {
 	retvalue result,r;
 	struct changes *changes;
 	struct trackingdata trackingdata;
 	char *directory;
 
-	r = changes_read(changesfilename,&changes,packagetypeonly,forcearchitecture,onlysigned);
+	r = changes_read(changesfilename,&changes,packagetypeonly,forcearchitecture);
 	if( RET_WAS_ERROR(r) )
 		return r;
 
+	if( (distribution->suite == NULL || 
+		!strlist_in(&changes->distributions,distribution->suite)) &&
+	    !strlist_in(&changes->distributions,distribution->codename) ) {
+		if( !IGNORING("Ignoring","To ignore",wrongdistribution,".changes put in a distribution not listed within it!\n") ) {
+			changes_free(changes);
+			return RET_ERROR;
+		}
+	}
+
+	if( uploaders != NULL ) {
+		const struct uploadpermissions *permissions;
+		int i;
+
+		if( changes->fingerprints.count == 0 ) {
+			r = uploaders_unsignedpermissions(uploaders, &permissions);
+			assert( r != RET_NOTHING );
+			if( RET_WAS_ERROR(r) ) {
+				changes_free(changes);
+				return r;
+			}
+			if( permissions == NULL || !permissionssuffice(changes,permissions) )
+				permissions = NULL;
+		}
+		for( i = 0; i < changes->fingerprints.count ; i++ ) {
+			const char *fingerprint = changes->fingerprints.values[i];
+			r = uploaders_permissions(uploaders, fingerprint, &permissions);
+			assert( r != RET_NOTHING );
+			if( RET_WAS_ERROR(r) ) {
+				changes_free(changes);
+				return r;
+			}
+			if( permissions != NULL && permissionssuffice(changes,permissions) )
+				break;
+			permissions = NULL;
+		}
+		if( permissions == NULL &&
+		    !IGNORING_(uploaders,"No rule allowing this package in found in %s!\n",
+			    distribution->uploaders) ) {
+			changes_free(changes);
+			return RET_ERROR;
+		}
+	}
+
 	if( IGNORABLE(missingfile) ) {
 		r = dirs_getdirectory(changesfilename,&directory);
 		if( RET_WAS_ERROR(r) ) {
@@ -958,15 +1022,6 @@ retvalue changes_add(const char *dbdir,trackingdb const tracks,references refs,f
 	} else
 		directory = NULL;
 
-	if( (distribution->suite == NULL || 
-		!strlist_in(&changes->distributions,distribution->suite)) &&
-	    !strlist_in(&changes->distributions,distribution->codename) ) {
-		if( !IGNORING("Ignoring","To ignore",wrongdistribution,".changes put in a distribution not listed within it!\n") ) {
-			free(directory);
-			changes_free(changes);
-			return RET_ERROR;
-		}
-	}
 
 	/* look for component, section and priority to be correct or guess them*/
 	r = changes_fixfields(distribution,changesfilename,changes,forcecomponent,forcesection,forcepriority,ao);
@@ -975,13 +1030,13 @@ retvalue changes_add(const char *dbdir,trackingdb const tracks,references refs,f
 	if( !RET_WAS_ERROR(r) )
 		r = changes_check(changesfilename,changes,forcearchitecture,packagetypeonly);
 
-	if( interupted() )
+	if( interrupted() )
 		RET_UPDATE(r,RET_ERROR_INTERUPTED);
 
 	if( !RET_WAS_ERROR(r) )
 		r = changes_checkfiles(filesdb,changesfilename,changes);
 
-	if( interupted() )
+	if( interrupted() )
 		RET_UPDATE(r,RET_ERROR_INTERUPTED);
 
 	/* add files in the pool */
@@ -989,7 +1044,7 @@ retvalue changes_add(const char *dbdir,trackingdb const tracks,references refs,f
 		r = changes_includefiles(filesdb,changes,delete);
 
 	if( !RET_WAS_ERROR(r) )
-		r = changes_checkpkgs(filesdb,distribution,changes,ao,onlysigned,directory);
+		r = changes_checkpkgs(filesdb,distribution,changes,ao,directory);
 
 	free(directory);
 
@@ -1017,7 +1072,7 @@ retvalue changes_add(const char *dbdir,trackingdb const tracks,references refs,f
 				trackingdata_done(&trackingdata);
 				return RET_ERROR_OOM;
 			}
-			if( interupted() )
+			if( interrupted() )
 				r = RET_ERROR_INTERUPTED;
 			else
 			/* always D_COPY, and only delete it afterwards... */
@@ -1031,7 +1086,7 @@ retvalue changes_add(const char *dbdir,trackingdb const tracks,references refs,f
 			}
 		}
 	}
-	if( interupted() ) {
+	if( interrupted() ) {
 		trackingdata_done(&trackingdata);
 		changes_free(changes);
 		return RET_ERROR_INTERUPTED;
