@@ -39,7 +39,7 @@ struct distribution {
 	/*@null@*/char *signwith;
 	/* the override file to use by default */
 	/*@null@*/char *deb_override,*udeb_override,*dsc_override;
-	/* the list of components containing a debian-installer dir, normaly only "main" */
+	/* the list of components containing a debian-installer dir, normally only "main" */
 	struct strlist udebcomponents;
 	/* what kind of index files to generate */
 	struct exportmode dsc,deb,udeb;
@@ -55,6 +55,8 @@ struct distribution {
 	struct contentsoptions contents;
 	/* A list of all targets contained in the distribution*/
 	struct target *targets;
+	/* a filename to look for who is allowed to upload packages */
+	char *uploaders;
 	/* RET_NOTHING: do not export with EXPORT_CHANGED, EXPORT_NEVER
 	 * RET_OK: export unless EXPORT_NEVER
 	 * RET_ERROR_*: only export with EXPORT_FORCE */
