@@ -23,6 +23,11 @@
 	IGN(extension) \
 	IGN(unusedarch) \
 	IGN(surprisingarch) \
+	IGN(surprisingbinary) \
+	IGN(wrongsourceversion) \
+	IGN(wrongversion) \
+	IGN(brokensignatures) \
+	IGN(uploaders) \
 	IGN(missingfile)
 
 
