@@ -1,7 +1,7 @@
 /*  This file is part of "reprepro"
  *  Copyright (C) 2003,2004,2005,2006 Bernhard R. Link
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as 
+ *  it under the terms of the GNU General Public License version 2 as
  *  published by the Free Software Foundation.
  *
  *  This program is distributed in the hope that it will be useful,
@@ -55,6 +55,8 @@
 #include "terms.h"
 #include "tracking.h"
 #include "optionsfile.h"
+#include "dpkgversions.h"
+#include "uploaderslist.h"
 
 
 #ifndef STD_BASE_DIR
@@ -73,7 +75,7 @@ static char /*@only@*/ /*@notnull@*/ // *g*
 	*confdir = NULL,
 	*overridedir = NULL,
 	*methoddir = NULL;
-static char /*@only@*/ /*@null@*/ 
+static char /*@only@*/ /*@null@*/
 	*section = NULL,
 	*priority = NULL,
 	*component = NULL,
@@ -85,7 +87,6 @@ static bool_t	nolistsdownload = FALSE;
 static bool_t	keepunreferenced = FALSE;
 static bool_t	keepunneededlists = FALSE;
 static bool_t	keepdirectories = FALSE;
-static bool_t	onlyacceptsigned = FALSE;
 static bool_t	askforpassphrase = FALSE;
 static bool_t	skipold = TRUE;
 static enum exportwhen export = EXPORT_NORMAL;
@@ -95,9 +96,9 @@ int		verbose = 0;
  * to change something owned by lower owners. */
 enum config_option_owner config_state,
 #define O(x) owner_ ## x = CONFIG_OWNER_DEFAULT
-O(mirrordir), O(distdir), O(dbdir), O(listdir), O(confdir), O(overridedir), O(methoddir), O(section), O(priority), O(component), O(architecture), O(packagetype), O(nothingiserror), O(nolistsdownload), O(keepunreferenced), O(keepunneededlists), O(keepdirectories), O(onlyacceptsigned),O(askforpassphrase), O(skipold), O(export);
+O(mirrordir), O(distdir), O(dbdir), O(listdir), O(confdir), O(overridedir), O(methoddir), O(section), O(priority), O(component), O(architecture), O(packagetype), O(nothingiserror), O(nolistsdownload), O(keepunreferenced), O(keepunneededlists), O(keepdirectories), O(askforpassphrase), O(skipold), O(export);
 #undef O
-	
+
 #define CONFIGSET(variable,value) if(owner_ ## variable <= config_state) { \
 					owner_ ## variable = config_state; \
 					variable = value; }
@@ -218,8 +219,8 @@ ACTION_N(extractcontrol) {
 	}
 
 	result = extractcontrol(&control,argv[1]);
-	
-	if( RET_IS_OK(result) ) 
+
+	if( RET_IS_OK(result) )
 		printf("%s\n",control);
 	return result;
 }
@@ -233,7 +234,7 @@ ACTION_N(extractfilelist) {
 	}
 
 	result = getfilelist(&filelist,argv[1]);
-	
+
 	if( RET_IS_OK(result) ) {
 		const char *p = filelist;
 		while( *p != '\0' ) {
@@ -267,7 +268,7 @@ ACTION_U_F(addmd5sums) {
 	}
 
 	result = RET_NOTHING;
-	
+
 	while( fgets(buffer,1999,stdin) != NULL ) {
 		c = strchr(buffer,'\n');
 		if( c == NULL ) {
@@ -317,7 +318,7 @@ static retvalue checkifreferenced(void *data,const char *filekey,UNUSED(const ch
 	r = references_isused(dist->refs,filekey);
 	if( r == RET_NOTHING ) {
 		printf("%s\n",filekey);
-		return RET_OK;		
+		return RET_OK;
 	} else if( RET_IS_OK(r) ) {
 		return RET_NOTHING;
 	} else
@@ -386,7 +387,7 @@ ACTION_R(addreference) {
 
 struct remove_args {/*@temp@*/references refs; int count; /*@temp@*/ const char * const *names; bool_t *gotremoved; int todo;/*@temp@*/struct strlist *removedfiles;/*@temp@*/struct trackingdata *trackingdata;};
 
-static retvalue remove_from_target(/*@temp@*/void *data, struct target *target, 
+static retvalue remove_from_target(/*@temp@*/void *data, struct target *target,
 		struct distribution *distribution) {
 	retvalue result,r;
 	int i;
@@ -489,7 +490,7 @@ ACTION_D(remove) {
 	return result;
 }
 
-static retvalue list_in_target(void *data, struct target *target, 
+static retvalue list_in_target(void *data, struct target *target,
 		UNUSED(struct distribution *distribution)) {
 	retvalue r,result;
 	const char *packagename = data;
@@ -625,7 +626,7 @@ ACTION_F(detect) {
 			*nl = '\0';
 			r = files_detect(filesdb,buffer);
 			RET_UPDATE(ret,r);
-		} 
+		}
 	return ret;
 }
 
@@ -650,7 +651,7 @@ ACTION_F(forget) {
 			*nl = '\0';
 			r = files_remove(filesdb, buffer, FALSE);
 			RET_UPDATE(ret,r);
-		} 
+		}
 	return ret;
 }
 
@@ -684,7 +685,7 @@ ACTION_N(dumpcontents) {
 
 	r = packages_done(packages);
 	RET_ENDUPDATE(result,r);
-	
+
 	return result;
 }
 
@@ -701,7 +702,7 @@ ACTION_F(export) {
 		fprintf(stderr, "Error: reprepro export incompatible with --export=never\n");
 		return RET_ERROR;
 	}
-	
+
 	result = distribution_getmatched(confdir,argc-1,argv+1,&distributions);
 	assert( result != RET_NOTHING);
 	if( RET_WAS_ERROR(result) )
@@ -714,8 +715,10 @@ ACTION_F(export) {
 
 		r = distribution_fullexport(d,confdir,dbdir,distdir,filesdb);
 		RET_UPDATE(result,r);
-		if( RET_WAS_ERROR(r) && export != EXPORT_FORCE)
+		if( RET_WAS_ERROR(r) && export != EXPORT_FORCE) {
+			distribution_freelist(distributions);
 			return r;
+		}
 	}
 	r = distribution_freelist(distributions);
 	RET_ENDUPDATE(result,r);
@@ -735,7 +738,7 @@ ACTION_D(update) {
 		return RET_ERROR;
 	}
 
-	result = dirs_make_recursive(listdir);	
+	result = dirs_make_recursive(listdir);
 	if( RET_WAS_ERROR(result) ) {
 		return result;
 	}
@@ -788,7 +791,7 @@ ACTION_D(predelete) {
 		return RET_ERROR;
 	}
 
-	result = dirs_make_recursive(listdir);	
+	result = dirs_make_recursive(listdir);
 	if( RET_WAS_ERROR(result) ) {
 		return result;
 	}
@@ -841,7 +844,7 @@ ACTION_D(iteratedupdate) {
 		return RET_ERROR;
 	}
 
-	result = dirs_make_recursive(listdir);	
+	result = dirs_make_recursive(listdir);
 	if( RET_WAS_ERROR(result) ) {
 		return result;
 	}
@@ -891,7 +894,7 @@ ACTION_N(checkupdate) {
 		return RET_ERROR;
 	}
 
-	result = dirs_make_recursive(listdir);	
+	result = dirs_make_recursive(listdir);
 	if( RET_WAS_ERROR(result) ) {
 		return result;
 	}
@@ -961,7 +964,7 @@ ACTION_D(pull) {
 		return result;
 	}
 	result = pull_update(dbdir,filesdb,references,p,dereferenced);
-	
+
 	pull_freerules(rules);
 	pull_freedistributions(p);
 	r = distribution_freelist(sourceonly);
@@ -1008,7 +1011,7 @@ ACTION_N(checkpull) {
 		return result;
 	}
 	result = pull_checkupdate(dbdir,p);
-	
+
 	pull_freerules(rules);
 	pull_freedistributions(p);
 	r = distribution_freelist(sourceonly);
@@ -1022,12 +1025,12 @@ ACTION_N(checkpull) {
 
 struct copy_data {
 	struct distribution *destination;
-	/*@temp@*/references refs; 
-	/*@temp@*/const char *name; 
+	/*@temp@*/references refs;
+	/*@temp@*/const char *name;
 	/*@temp@*/struct strlist *removedfiles;
 };
 
-static retvalue copy(/*@temp@*/void *data, struct target *origtarget, 
+static retvalue copy(/*@temp@*/void *data, struct target *origtarget,
 		struct distribution *distribution) {
 	retvalue result,r;
 	struct copy_data *d = data;
@@ -1128,7 +1131,7 @@ ACTION_D(copy) {
 	if( destination->tracking != dt_NONE ) {
 		fprintf(stderr, "WARNING: copy does not yet support trackingdata and will ignore trackingdata in '%s'!\n", destination->codename);
 	}
-	
+
 	d.destination = destination;
 	d.refs = references;
 	d.removedfiles = dereferenced;
@@ -1150,7 +1153,7 @@ ACTION_D(copy) {
 	distribution_free(source);
 	distribution_free(destination);
 	return result;
-	
+
 }
 
 /***********************rereferencing*************************/
@@ -1301,7 +1304,7 @@ ACTION_D_U(removetrack) {
 	RET_ENDUPDATE(result,r);
 	return result;
 }
-	
+
 ACTION_D(cleartracks) {
 	retvalue result,r;
 	struct distribution *distributions,*d;
@@ -1503,13 +1506,6 @@ ACTION_F(reoverride) {
 
 /***********************include******************************************/
 
-static inline bool_t endswith(const char *name, const char *suffix) {
-	size_t ln,ls;
-	ln = strlen(name);
-	ls = strlen(suffix);
-	return ln > ls && strcmp(name+(ln-ls),suffix) == 0;
-}
-
 ACTION_D(includedeb) {
 	retvalue result,r;
 	struct distribution *distribution;
@@ -1526,10 +1522,6 @@ ACTION_D(includedeb) {
 		fprintf(stderr,"Error: -A source is not possible with includedeb!\n");
 		return RET_ERROR;
 	}
-	if( onlyacceptsigned ) {
-		fprintf(stderr,"include[u]deb together with --onlyacceptsigned is not yet possible,\n as .[u]deb files cannot be signed yet.\n");
-		return RET_ERROR;
-	}
 	if( strcmp(argv[0],"includeudeb") == 0 ) {
 		isudeb = TRUE;
 		if( packagetype != NULL && strcmp(packagetype,"udeb") != 0 ) {
@@ -1664,8 +1656,8 @@ ACTION_D(includedsc) {
 		tracks = NULL;
 	}
 
-	result = dsc_add(dbdir,references,filesdb,component,section,priority,distribution,argv[2],srcoverride,delete,dereferenced,onlyacceptsigned,tracks);
-	
+	result = dsc_add(dbdir,references,filesdb,component,section,priority,distribution,argv[2],srcoverride,delete,dereferenced,tracks);
+
 	override_free(srcoverride);
 	r = tracking_done(tracks);
 	RET_ENDUPDATE(result,r);
@@ -1681,6 +1673,7 @@ ACTION_D(include) {
 	retvalue result,r;
 	struct distribution *distribution;
 	struct alloverrides ao;
+	struct uploaders *uploaders;
 	trackingdb tracks;
 
 	if( argc != 3 ) {
@@ -1688,7 +1681,7 @@ ACTION_D(include) {
 		return RET_ERROR;
 	}
 	if( !endswith(argv[2],".changes") && !IGNORING_(extension,
-				"include called with a file not ending with '.change'\n"
+				"include called with a file not ending with '.changes'\n"
 				"(Did you mean includedeb or includedsc?)\n") )
 		return RET_ERROR;
 
@@ -1729,11 +1722,23 @@ ACTION_D(include) {
 	} else {
 		tracks = NULL;
 	}
+	if( distribution->uploaders != NULL ) {
+		result = uploaders_load(&uploaders, confdir, distribution->uploaders);
+		if( RET_WAS_ERROR(result) ) {
+			r = tracking_done(tracks);
+			RET_ENDUPDATE(result,r);
+			override_free(ao.deb);override_free(ao.udeb);override_free(ao.dsc);
+			r = distribution_free(distribution);
+			RET_ENDUPDATE(result,r);
+			return result;
+		}
+	} else
+		uploaders = NULL;
 
-	result = changes_add(dbdir,tracks,references,filesdb,packagetype,component,architecture,section,priority,distribution,&ao,argv[2],delete,dereferenced,onlyacceptsigned);
+	result = changes_add(dbdir,tracks,references,filesdb,packagetype,component,architecture,section,priority,distribution,uploaders,&ao,argv[2],delete,dereferenced);
 
 	override_free(ao.deb);override_free(ao.udeb);override_free(ao.dsc);
-
+	uploaders_free(uploaders);
 	r = tracking_done(tracks);
 	RET_ENDUPDATE(result,r);
 	r = distribution_export(export,distribution,confdir,dbdir,distdir,filesdb);
@@ -1764,7 +1769,7 @@ ACTION_N(createsymlinks) {
 		char *linkname,*buffer;
 		size_t bufsize;
 		int ret;
-		
+
 		if( d->suite == NULL )
 			continue;
 		r = RET_NOTHING;
@@ -1944,6 +1949,35 @@ ACTION_D_UU(clearvanished) {
 	return result;
 }
 
+ACTION_N(versioncompare) {
+	retvalue r;
+	int i;
+
+	if( argc != 3 ) {
+		fprintf(stderr,"reprepro versioncompare <version> <version>\n");
+		return RET_ERROR;
+	}
+	r = properversion(argv[1]);
+	if( RET_WAS_ERROR(r) )
+		fprintf(stderr, "'%s' is not a proper version!\n", argv[1]);
+	r = properversion(argv[2]);
+	if( RET_WAS_ERROR(r) )
+		fprintf(stderr, "'%s' is not a proper version!\n", argv[2]);
+	r = dpkgversions_cmp(argv[1],argv[2],&i);
+	if( RET_IS_OK(r) ) {
+		if( i < 0 ) {
+			fprintf(stderr, "'%s' is smaller than '%s'.\n",
+						argv[1], argv[2]);
+		} else if( i > 0 ) {
+			fprintf(stderr, "'%s' is larger than '%s'.\n",
+					argv[1], argv[2]);
+		} else
+			fprintf(stderr, "'%s' is the same as '%s'.\n",
+					argv[1], argv[2]);
+	}
+	return r;
+}
+
 /**********************/
 /* lock file handling */
 /**********************/
@@ -1953,7 +1987,7 @@ static retvalue acquirelock(const char *dbdir) {
 	int fd;
 	retvalue r;
 
-	// TODO: create directory 
+	// TODO: create directory
 	r = dirs_make_recursive(dbdir);
 	if( RET_WAS_ERROR(r) )
 		return r;
@@ -1984,7 +2018,7 @@ static retvalue acquirelock(const char *dbdir) {
 		(void)unlink(lockfile);
 		free(lockfile);
 		return RET_ERRNO(e);
-	
+
 	}
 	free(lockfile);
 	return RET_OK;
@@ -2016,12 +2050,12 @@ static void releaselock(const char *dbdir) {
 #define A_R(w) action_r_ ## w, NEED_REFERENCES
 #define A_RF(w) action_rf_ ## w, NEED_FILESDB|NEED_REFERENCES
 /* to dereference files, one needs files and references database: */
-#define A_D(w) action_d_ ## w, NEED_FILESDB|NEED_REFERENCES|NEED_DEREF 
+#define A_D(w) action_d_ ## w, NEED_FILESDB|NEED_REFERENCES|NEED_DEREF
 
 static const struct action {
 	char *name;
 	retvalue (*start)(
-			/*@null@*/references references, 
+			/*@null@*/references references,
 			/*@null@*/filesdb filesdb,
 			/*@null@*/struct strlist *dereferencedfilekeys,
 			int argc,const char *argv[]);
@@ -2037,6 +2071,7 @@ static const struct action {
 	{"_dumpcontents", 	A_N(dumpcontents)},
 	{"_removereferences", 	A_R(removereferences)},
 	{"_addreference", 	A_R(addreference)},
+	{"_versioncompare",	A_N(versioncompare)},
 	{"remove", 		A_D(remove)},
 	{"list", 		A_N(list)},
 	{"listfilter", 		A_N(listfilter)},
@@ -2082,9 +2117,9 @@ static retvalue callaction(const struct action *action,int argc,const char *argv
 	bool_t deletederef;
 
 	assert(action != NULL);
-	
+
 	deletederef = ISSET(action->needs,NEED_DEREF) && !keepunreferenced;
-	
+
 	result = acquirelock(dbdir);
 	if( !RET_IS_OK(result) )
 		return result;
@@ -2108,18 +2143,17 @@ static retvalue callaction(const struct action *action,int argc,const char *argv
 			if( deletederef ) {
 				assert( ISSET(action->needs,NEED_REFERENCES) );
 				assert( ISSET(action->needs,NEED_REFERENCES) );
-				result = strlist_init(&dereferencedfilekeys);
+				strlist_init(&dereferencedfilekeys);
 			}
 
-			assert( result != RET_NOTHING );
-			if( RET_IS_OK(result) && !interupted() ) {
+			if( !interrupted() ) {
 				result = action->start(references,filesdb,
 					deletederef?&dereferencedfilekeys:NULL,
 					argc,argv);
 
 				if( deletederef ) {
 					if( dereferencedfilekeys.count > 0 ) {
-					    if( RET_IS_OK(result) && !interupted() ) {
+					    if( RET_IS_OK(result) && !interrupted() ) {
 						retvalue r;
 
 						assert(filesdb!=NULL);
@@ -2162,7 +2196,6 @@ LO_KEEPUNREFERENCED,
 LO_KEEPUNNEEDEDLISTS,
 LO_NOTHINGISERROR,
 LO_NOLISTDOWNLOAD,
-LO_ONLYACCEPTSIGNED,
 LO_ASKPASSPHRASE,
 LO_KEEPDIRECTORIES,
 LO_SKIPOLD,
@@ -2171,7 +2204,6 @@ LO_NOKEEPUNREFERENCED,
 LO_NOKEEPUNNEEDEDLISTS,
 LO_NONOTHINGISERROR,
 LO_LISTDOWNLOAD,
-LO_NOONLYACCEPTSIGNED,
 LO_NOASKPASSPHRASE,
 LO_NOKEEPDIRECTORIES,
 LO_NOSKIPOLD,
@@ -2277,12 +2309,6 @@ static void handle_option(int c,const char *optarg) {
 				case LO_NODELETE:
 					delete--;
 					break;
-				case LO_ONLYACCEPTSIGNED:
-					CONFIGSET(onlyacceptsigned,TRUE);
-					break;
-				case LO_NOONLYACCEPTSIGNED:
-					CONFIGSET(onlyacceptsigned,FALSE);
-					break;
 				case LO_KEEPUNREFERENCED:
 					CONFIGSET(keepunreferenced,TRUE);
 					break;
@@ -2374,7 +2400,7 @@ static void handle_option(int c,const char *optarg) {
 			}
 			break;
 		case 'C':
-			if( component != NULL && 
+			if( component != NULL &&
 					strcmp(component,optarg) != 0) {
 				fprintf(stderr,"Multiple '-C' are not supported!\n");
 				exit(EXIT_FAILURE);
@@ -2382,7 +2408,7 @@ static void handle_option(int c,const char *optarg) {
 			CONFIGDUP(component,optarg);
 			break;
 		case 'A':
-			if( architecture != NULL && 
+			if( architecture != NULL &&
 					strcmp(architecture,optarg) != 0) {
 				fprintf(stderr,"Multiple '-A's are not supported!\n");
 				exit(EXIT_FAILURE);
@@ -2390,7 +2416,7 @@ static void handle_option(int c,const char *optarg) {
 			CONFIGDUP(architecture,optarg);
 			break;
 		case 'T':
-			if( packagetype != NULL && 
+			if( packagetype != NULL &&
 					strcmp(packagetype,optarg) != 0) {
 				fprintf(stderr,"Multiple '-T's are not supported!\n");
 				exit(EXIT_FAILURE);
@@ -2398,7 +2424,7 @@ static void handle_option(int c,const char *optarg) {
 			CONFIGDUP(packagetype,optarg);
 			break;
 		case 'S':
-			if( section != NULL && 
+			if( section != NULL &&
 					strcmp(section,optarg) != 0) {
 				fprintf(stderr,"Multiple '-S' are not supported!\n");
 				exit(EXIT_FAILURE);
@@ -2406,7 +2432,7 @@ static void handle_option(int c,const char *optarg) {
 			CONFIGDUP(section,optarg);
 			break;
 		case 'P':
-			if( priority != NULL && 
+			if( priority != NULL &&
 					strcmp(priority,optarg) != 0) {
 				fprintf(stderr,"Multiple '-P's are mpt supported!\n");
 				exit(EXIT_FAILURE);
@@ -2422,23 +2448,23 @@ static void handle_option(int c,const char *optarg) {
 	}
 }
 
-static volatile bool_t was_interupted = FALSE;
-static bool_t interuption_printed = FALSE;
+static volatile bool_t was_interrupted = FALSE;
+static bool_t interruption_printed = FALSE;
 
-bool_t interupted(void) {
-	if( was_interupted ) {
-		if( !interuption_printed ) {
-			interuption_printed = TRUE;
-			fprintf(stderr, "\n\nInteruption in progress, interupt again to force-stop it (and risking database corruption!)\n\n");
+bool_t interrupted(void) {
+	if( was_interrupted ) {
+		if( !interruption_printed ) {
+			interruption_printed = TRUE;
+			fprintf(stderr, "\n\nInterruption in progress, interrupt again to force-stop it (and risking database corruption!)\n\n");
 		}
 		return TRUE;
 	} else
 		return FALSE;
 }
 
-static void interupt_signaled(int signal) /*__attribute__((signal))*/;
-static void interupt_signaled(UNUSED(int signal)) {
-	was_interupted = TRUE;
+static void interrupt_signaled(int signal) /*__attribute__((signal))*/;
+static void interrupt_signaled(UNUSED(int signal)) {
+	was_interrupted = TRUE;
 }
 
 int main(int argc,char *argv[]) {
@@ -2468,7 +2494,6 @@ int main(int argc,char *argv[]) {
 		{"keepunreferencedfiles", no_argument, &longoption, LO_KEEPUNREFERENCED},
 		{"keepunneededlists", no_argument, &longoption, LO_KEEPUNNEEDEDLISTS},
 		{"keepdirectories", no_argument, &longoption, LO_KEEPDIRECTORIES},
-		{"onlyacceptsigned", no_argument, &longoption, LO_ONLYACCEPTSIGNED},
 		{"ask-passphrase", no_argument, &longoption, LO_ASKPASSPHRASE},
 		{"nonothingiserror", no_argument, &longoption, LO_NONOTHINGISERROR},
 		{"nonolistsdownload", no_argument, &longoption, LO_LISTDOWNLOAD},
@@ -2476,7 +2501,6 @@ int main(int argc,char *argv[]) {
 		{"nokeepunreferencedfiles", no_argument, &longoption, LO_NOKEEPUNREFERENCED},
 		{"nokeepunneededlists", no_argument, &longoption, LO_NOKEEPUNNEEDEDLISTS},
 		{"nokeepdirectories", no_argument, &longoption, LO_NOKEEPDIRECTORIES},
-		{"noonlyacceptsigned", no_argument, &longoption, LO_NOONLYACCEPTSIGNED},
 		{"noask-passphrase", no_argument, &longoption, LO_NOASKPASSPHRASE},
 		{"skipold", no_argument, &longoption, LO_SKIPOLD},
 		{"noskipold", no_argument, &longoption, LO_NOSKIPOLD},
@@ -2492,7 +2516,7 @@ int main(int argc,char *argv[]) {
 
 	sigemptyset(&sa.sa_mask);
 	sa.sa_flags = SA_ONESHOT;
-	sa.sa_handler = interupt_signaled;
+	sa.sa_handler = interrupt_signaled;
 	(void)sigaction(SIGTERM, &sa, NULL);
 	(void)sigaction(SIGABRT, &sa, NULL);
 	(void)sigaction(SIGINT, &sa, NULL);
@@ -2504,7 +2528,7 @@ int main(int argc,char *argv[]) {
 
 	config_state = CONFIG_OWNER_CMDLINE;
 
-	if( interupted() ) 
+	if( interrupted() )
 		exit(EXIT_RET(RET_ERROR_INTERUPTED));
 
 	while( (c = getopt_long(argc,argv,"+fVvhb:P:i:A:C:S:T:",longopts,NULL)) != -1 ) {
@@ -2514,7 +2538,7 @@ int main(int argc,char *argv[]) {
 		fprintf(stderr,"No action given. (see --help for available options and actions)\n");
 		exit(EXIT_FAILURE);
 	}
-	if( interupted() ) 
+	if( interrupted() )
 		exit(EXIT_RET(RET_ERROR_INTERUPTED));
 
 	/* only for this CONFIG_OWNER_ENVIRONMENT is a bit stupid,
@@ -2557,12 +2581,12 @@ int main(int argc,char *argv[]) {
 		listdir=calc_dirconcat(mirrordir,"lists");
 	if( overridedir == NULL )
 		overridedir=calc_dirconcat(mirrordir,"override");
-	if( distdir == NULL || dbdir == NULL || listdir == NULL 
+	if( distdir == NULL || dbdir == NULL || listdir == NULL
 			|| confdir == NULL || overridedir == NULL || methoddir == NULL) {
 		(void)fputs("Out of Memory!\n",stderr);
 		exit(EXIT_FAILURE);
 	}
-	if( interupted() ) 
+	if( interrupted() )
 		exit(EXIT_RET(RET_ERROR_INTERUPTED));
 	a = all_actions;
 	while( a->name != NULL ) {
@@ -2570,7 +2594,7 @@ int main(int argc,char *argv[]) {
 			signature_init(askforpassphrase);
 			r = callaction(a,argc-optind,(const char**)argv+optind);
 			/* yeah, freeing all this stuff before exiting is
-			 * stupid, but it makes valgrind logs easier 
+			 * stupid, but it makes valgrind logs easier
 			 * readable */
 			signatures_done();
 			free(dbdir);
