@@ -1,9 +1,8 @@
 /*  This file is part of "reprepro"
  *  Copyright (C) 2003,2004,2005 Bernhard R. Link
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  it under the terms of the GNU General Public License version 2 as 
+ *  published by the Free Software Foundation.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -116,7 +115,8 @@ retvalue packages_initialize(packagesdb *db,const char *dbpath,const char *ident
 	isopen++;
 	if( isopen > 1 )
 		fprintf(stderr,"isopen: %d\n",isopen);
-	if ((dbret = pkgs->database->open(pkgs->database, filename, identifier, DB_BTREE, DB_CREATE, 0664)) != 0) {
+	dbret = DB_OPEN(pkgs->database, filename, identifier, DB_BTREE, DB_CREATE);
+	if (dbret != 0) {
 		pkgs->database->err(pkgs->database, dbret, "%s(%s)", filename,identifier);
 		(void)pkgs->database->close(pkgs->database,0);
 		free(filename);
@@ -236,7 +236,7 @@ static retvalue package_check(packagesdb db,const char *package) {
 //typedef retvalue per_package_action(void *data,const char *package,const char *chunk);
 
 /* call action once for each saved chunk: */
-retvalue packages_foreach(packagesdb db,per_package_action action,void *privdata, int force) {
+retvalue packages_foreach(packagesdb db,per_package_action action,void *privdata) {
 	DBC *cursor;
 	DBT key,data;
 	int dbret;
@@ -254,9 +254,9 @@ retvalue packages_foreach(packagesdb db,per_package_action action,void *privdata
 	while( (dbret=cursor->c_get(cursor,&key,&data,DB_NEXT)) == 0 ) {
 		r = action(privdata,(const char*)key.data,(const char*)data.data);
 		RET_UPDATE(ret,r);
-		if( RET_WAS_ERROR(r) && force <= 0 ) {
+		if( RET_WAS_ERROR(r) ) {
 			if( verbose > 0 )
-				fprintf(stderr,"packages_foreach: Stopping procession of further packages due to privious errors\n");
+				fprintf(stderr,"packages_foreach: Stopping procession of further packages due to previous errors\n");
 			break;
 		}
 		CLEARDBT(key);	
@@ -381,3 +381,109 @@ retvalue packages_insert(references refs, packagesdb packagesdb,
 	return result;
 }
 
+/* Get a list of all identifiers having a package list */
+retvalue packages_getdatabases(const char *dbpath, struct strlist *identifiers) {
+	char *filename;
+	DB *database;
+	DBC *cursor;
+	DBT key,data;
+	int dbret;
+	retvalue ret,r;
+	struct strlist ids;
+
+	filename = calc_dirconcat(dbpath, "packages.db");
+	if( filename == NULL )
+		return RET_ERROR_OOM;
+	
+	if ((dbret = db_create(&database, NULL, 0)) != 0) {
+		fprintf(stderr, "db_create: %s %s\n", filename,db_strerror(dbret));
+		free(filename);
+		return RET_DBERR(dbret);
+	}
+	dbret = DB_OPEN(database, filename, NULL, DB_UNKNOWN, DB_RDONLY);
+	if (dbret != 0) {
+		database->err(database, dbret, "%s", filename);
+		(void)database->close(database,0);
+		free(filename);
+		return RET_DBERR(dbret);
+	}                     
+	free(filename);
+
+	cursor = NULL;
+	if( (dbret = database->cursor(database,NULL,&cursor,0)) != 0 ) {
+		database->err(database, dbret, "packages.db:");
+		(void)database->close(database,0);
+		return RET_ERROR;
+	}
+	CLEARDBT(key);
+	CLEARDBT(data);
+
+	strlist_init(&ids);
+
+	ret = RET_NOTHING;
+	while( (dbret=cursor->c_get(cursor,&key,&data,DB_NEXT)) == 0 ) {
+		char *identifier = strndup(key.data,key.size);
+		if( identifier == NULL ) {
+			(void)database->close(database,0);
+			strlist_done(&ids);
+			return RET_ERROR_OOM;
+		}
+		r = strlist_add(&ids, identifier);
+		if( RET_WAS_ERROR(r) ) {
+			(void)database->close(database,0);
+			strlist_done(&ids);
+			return r;
+		}
+		CLEARDBT(key);	
+		CLEARDBT(data);
+	}
+
+	if( dbret != 0 && dbret != DB_NOTFOUND ) {
+		database->err(database, dbret, "packages.db:");
+		(void)database->close(database,0);
+		strlist_done(&ids);
+		return RET_DBERR(dbret);
+	}
+	if( (dbret = cursor->c_close(cursor)) != 0 ) {
+		database->err(database, dbret, "packages.db:");
+		(void)database->close(database,0);
+		strlist_done(&ids);
+		return RET_DBERR(dbret);
+	}
+
+	dbret = database->close(database,0);
+	if( dbret != 0 ) {
+		strlist_done(&ids);
+		return RET_DBERR(dbret);
+	} else {
+		strlist_move(identifiers, &ids);
+		return RET_OK;
+	}
+}
+
+/* drop a database */
+retvalue packages_drop(const char *dbpath, const char *identifier) {
+	char *filename;
+	DB *database;
+	int dbret;
+
+	filename = calc_dirconcat(dbpath, "packages.db");
+	if( filename == NULL )
+		return RET_ERROR_OOM;
+	
+	if ((dbret = db_create(&database, NULL, 0)) != 0) {
+		fprintf(stderr, "db_create: %s %s\n", filename, db_strerror(dbret));
+		free(filename);
+		return RET_DBERR(dbret);
+	}
+	dbret = database->remove(database, filename, identifier, 0);
+	if (dbret != 0) {
+		fprintf(stderr,"Error removing '%s' from %s!\n",
+				identifier, filename);
+		free(filename);
+		return RET_DBERR(dbret);
+	}                     
+
+	free(filename);
+	return RET_OK;
+}
