@@ -61,7 +61,7 @@ retvalue packages_insert(references refs, packagesdb packagesdb,
 typedef retvalue per_package_action(void *data,const char *package,/*@temp@*/const char *chunk);
 
 /* call action once for each saved chunk: */
-retvalue packages_foreach(packagesdb packagesdb,per_package_action *action,/*@temp@*/ /*@null@*/void *data, int force);
+retvalue packages_foreach(packagesdb packagesdb,per_package_action *action,/*@temp@*/ /*@null@*/void *data);
 
 /* action to be called by packages_modifyall */
 struct alloverrides;
@@ -69,4 +69,8 @@ typedef retvalue per_package_modifier(const struct alloverrides *data,const char
 /* call action once for each saved chunk and replace with a new one, if it returns RET_OK: */
 retvalue packages_modifyall(packagesdb db,per_package_modifier *action,void *privdata,bool_t *setifmodified);
 
+/* get a list of all identifiers once created */
+retvalue packages_getdatabases(const char *dbpath, struct strlist *identifiers);
+/* remove the package database for the given identifier */
+retvalue packages_drop(const char *dbpath, const char *identifier);
 #endif
