@@ -14,7 +14,7 @@ retvalue signature_check(const char *options, const char *releasegpg, const char
 retvalue signature_sign(const char *options, const char *filename, const char *signeturename);
 
 /* Read a single chunk from a file, that may be signed. */
-retvalue signature_readsignedchunk(const char *filename, char **chunkread, bool_t onlyacceptsigned);
+retvalue signature_readsignedchunk(const char *filename, char **chunkread, /*@null@*/ /*@out@*/struct strlist *validkeys, /*@null@*/ /*@out@*/ struct strlist *allkeys, bool_t *brokensignature);
 
 void signatures_done(void);
 
