@@ -348,7 +348,7 @@ retvalue sources_doreoverride(const struct alloverrides *ao,const char *packagen
 	struct fieldtoadd *fields;
 	char *newchunk;
 
-	if( interupted() )
+	if( interrupted() )
 		return RET_ERROR_INTERUPTED;
 
 	o = override_search(ao->dsc, packagename);
@@ -375,7 +375,7 @@ retvalue sources_retrack(struct target *t,const char *sourcename,const char *chu
 	//TODO: elliminate duplicate code!
 	assert(sourcename!=NULL);
 
-	if( interupted() )
+	if( interrupted() )
 		return RET_ERROR_INTERUPTED;
 
 	r = chunk_getvalue(chunk,"Version",&sourceversion);
