@@ -1,9 +1,8 @@
 /*  This file is part of "reprepro"
  *  Copyright (C) 2004,2005 Bernhard R. Link
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  it under the terms of the GNU General Public License version 2 as 
+ *  published by the Free Software Foundation.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -309,7 +308,7 @@ static retvalue rereferencepkg(void *data,const char *package,const char *chunk)
 	return r;
 }
 
-retvalue target_rereference(struct target *target,references refs,int force) {
+retvalue target_rereference(struct target *target,references refs) {
 	retvalue result,r;
 	struct data_reref refdata;
 
@@ -322,14 +321,14 @@ retvalue target_rereference(struct target *target,references refs,int force) {
 			fprintf(stderr,"Rereferencing %s...\n",target->identifier);
 	}
 
-	result = references_remove(refs,target->identifier);
+	result = references_remove(refs,target->identifier, NULL);
 
 	if( verbose > 2 )
 		fprintf(stderr,"Referencing %s...\n",target->identifier);
 
 	refdata.refs = refs;
 	refdata.target = target;
-	r = packages_foreach(target->packages,rereferencepkg,&refdata,force);
+	r = packages_foreach(target->packages,rereferencepkg,&refdata);
 	RET_UPDATE(result,r);
 	
 	return result;
@@ -350,7 +349,7 @@ static retvalue retrackpkg(void *data,const char *package,const char *chunk) {
 	return r;
 }
 
-retvalue target_retrack(struct target *target,trackingdb tracks,references refs,int force) {
+retvalue target_retrack(struct target *target,trackingdb tracks,references refs) {
 	struct data_retrack trackdata;
 
 	assert(target->packages!=NULL);
@@ -362,7 +361,7 @@ retvalue target_retrack(struct target *target,trackingdb tracks,references refs,
 	trackdata.refs = refs;
 	trackdata.tracks = tracks;
 	trackdata.target = target;
-	return packages_foreach(target->packages,retrackpkg,&trackdata,force);
+	return packages_foreach(target->packages,retrackpkg,&trackdata);
 }
 
 
@@ -432,7 +431,7 @@ static retvalue checkpkg(void *data,const char *package,const char *chunk) {
 	return result;
 }
 
-retvalue target_check(struct target *target,filesdb filesdb,references refs,int force) {
+retvalue target_check(struct target *target,filesdb filesdb,references refs) {
 	struct data_check data;
 
 	assert(target->packages!=NULL);
@@ -442,7 +441,7 @@ retvalue target_check(struct target *target,filesdb filesdb,references refs,int
 	data.refs = refs;
 	data.filesdb = filesdb;
 	data.target = target;
-	return packages_foreach(target->packages,checkpkg,&data,force);
+	return packages_foreach(target->packages,checkpkg,&data);
 }
 
 /* Reapply override information */
@@ -486,6 +485,8 @@ retvalue target_export(struct target *target,const char *confdir,const char *dbd
 	RET_ENDUPDATE(result,r);
 
 	if( !RET_WAS_ERROR(result) ) {
+		target->saved_wasmodified =
+			target->saved_wasmodified || target->wasmodified;
 		target->wasmodified = FALSE;
 	}
 	return result;
