@@ -51,7 +51,7 @@ struct target {
 	get_sourceandversion *getsourceandversion;
 	do_reoverride *doreoverride;
 	do_retrack *doretrack;
-	bool_t wasmodified;
+	bool_t wasmodified, saved_wasmodified;
 	/* the next one in the list of targets of a distribution */
 	struct target *next;
 	/* is initialized as soon as needed: */
@@ -77,10 +77,9 @@ retvalue target_closepackagesdb(struct target *target);
 
 retvalue target_addpackage(struct target *target,references refs,const char *name,const char *version,const char *control,const struct strlist *filekeys,bool_t downgrade,/*@null@*/struct strlist *dereferencedfilekeys,/*@null@*/struct trackingdata *,enum filetype);
 retvalue target_removepackage(struct target *target,references refs,const char *name, /*@null@*/struct strlist *dereferencedfilekeys,struct trackingdata *);
-retvalue target_writeindices(const char *dirofdist,struct target *target,int force,bool_t onlyneeded);
-retvalue target_check(struct target *target,filesdb filesdb,references refsdb,int force);
-retvalue target_rereference(struct target *target,references refs,int force);
-retvalue target_retrack(struct target *target,trackingdb tracks,references refs,int force);
+retvalue target_check(struct target *target,filesdb filesdb,references refsdb);
+retvalue target_rereference(struct target *target,references refs);
+retvalue target_retrack(struct target *target,trackingdb tracks,references refs);
 retvalue target_reoverride(struct target *target,const struct alloverrides *ao);
 
 #endif
