@@ -16,6 +16,7 @@ Source: $PACKAGE
 Section: $SECTION
 Priority: superfluous
 Maintainer: me <guess@who>
+Standards-Version: 0.0
 
 Package: $PACKAGE
 Architecture: abacus
@@ -27,8 +28,11 @@ Architecture: all
 Description: bla
  blub
 END
+if test -z "$DISTRI" ; then
+	DISTRI=test1
+fi
 cat >"$DIR"/debian/changelog <<END
-$PACKAGE ($EPOCH$VERSION$REVISION) test1; urgency=critical
+$PACKAGE ($EPOCH$VERSION$REVISION) $DISTRI; urgency=critical
 
    * new upstream release (Closes: #allofthem)
 
@@ -43,4 +47,6 @@ for pkg in `grep '^Package: ' debian/control | sed -e 's/^Package: //'` ; do
 	dpkg --build debian/tmp .. 
 done
 #dpkg-genchanges > ../"${PACKAGE}_$VERSION$REVISION"_abbacus.changes
-dpkg-genchanges > ../"$OUTPUT"
+dpkg-genchanges "$@" > ../"$OUTPUT"
+cd ..
+rm -r "$DIR"
